@@ -153,6 +153,28 @@ sub update {
     $self->SUPER::update($data, %opt);
 }
 
+=head2 delete
+
+    my $meeting = Elive::Entity::Meeting->retrieve([$meeting_id]);
+    $meeting->delete
+
+Delete the meeting.
+
+Note: With Elluminate 9.5 onwards, deleting a meetings simply sets the
+I<deleted> property to true. Meetings, Meeting Parameters and Server
+Parameters remain accessable via the SOAP inteface.
+
+If you only want live meetings, you'll need to filter:
+
+    my $meeting =  Elive::Entity::Meeting->retreive([$meeting_id]);
+    my $is_live = $meeting->deleted;
+
+or check individual meetings:
+
+    my $live_meetings =  Elive::Entity::Meeting->list(filter => 'deleted = false');
+
+=cut
+
 =head2 list_user_meetings_by_date
 
 List all meetings over a given date range.
@@ -411,9 +433,11 @@ sub remove_preload {
     
 =head2 buildJNLP 
 
-    my $jnlp = $meeting_entity->buildJNLP(version => version,
-					  user => userId|userName,
-					  pass => password);
+    my $jnlp = $meeting_entity->buildJNLP(version => $version,
+					  user => $userId||$userName,
+					  pass => $password,
+                                          displayName => 'Display Name'
+    );
 
 Builds a JNLP for the meeting.
 
@@ -445,10 +469,10 @@ sub buildJNLP {
 
     my %soap_params = (meetingId => $meeting_id);
 
-    foreach my $param (qw(version password)) {
+    foreach my $param (qw(version password displayName)) {
 	my $val = delete $opt{$param};
 	$soap_params{$param} = Elive::Util::_freeze($val, 'Str')
-	    if $val;
+	    if defined $val;
     }
 
     for (delete $opt{user} || $connection->login->userId) {
@@ -615,10 +639,17 @@ sub list_recordings {
     
 =head1 SEE ALSO
 
-Elive::Entity::Preload
-Elive::Entity::Recording
-Elive::Entity::MeetingParameters 
-Elive::Entity::ServerParameters
+=over 4
+
+=item Elive::Entity::Preload
+
+=item Elive::Entity::Recording
+
+=item Elive::Entity::MeetingParameters 
+
+=item Elive::Entity::ServerParameters
+
+=back
 
 =cut
 
